@@ -312,7 +312,7 @@ class Block(ABC):
 
         if not c_fuel == 0:
 
-            r = (c_prod - c_fuel) / c_fuel
+            r = (self.output_cost - c_fuel) / c_fuel
 
         if not (self.comp_cost + c_dest * abs(dest_loss_exergy)) == 0:
 
@@ -324,12 +324,12 @@ class Block(ABC):
 
         self.coefficients.update({
 
-                "r": r,
-                "f": f,
-                "y": y,
-                "eta": eta,
-                "c_fuel": c_fuel,
-                "c_dest": c_dest
+            "r": r,
+            "f": f,
+            "y": y,
+            "eta": eta,
+            "c_fuel": c_fuel,
+            "c_dest": c_dest
 
         })
 
@@ -788,11 +788,9 @@ class Block(ABC):
     def first_non_support_block(self):
 
         if not self.is_support_block:
-
             return self
 
         if self.is_support_block:
-
             return self.main_block.first_non_support_block
 
     # -------------------------------------
@@ -1173,7 +1171,7 @@ class Connection:
     @property
     def abs_cost(self) -> float:
 
-        return self.rel_cost * self.exergy_value
+        return self.__rel_cost * self.exergy_value
 
     @property
     def rel_cost(self) -> float:
@@ -1382,7 +1380,7 @@ class ArrayHandler:
 
                 self.append_solution(sol)
                 self.calculate_coefficients()
-                self.decompose_component_output_cost(matrix_analyzer)
+                self.decompose_component_output_cost()
 
     def append_solution(self, sol):
 
@@ -1412,13 +1410,13 @@ class ArrayHandler:
 
             block.calculate_coefficients(total_destruction)
 
-    def decompose_component_output_cost(self, analizer:MatrixAnalyzer):
+    def decompose_component_output_cost(self):
 
         if self.options.calculate_component_decomposition:
 
             try:
 
-                __inverse_matrix = analizer.inverse_matrix
+                __inverse_matrix = np.linalg.inv(self.matrix)
 
                 for block in self.block_list:
 
@@ -1998,7 +1996,7 @@ class CalculationOptions:
         self.valve_is_dissipative = True
         self.condenser_is_dissipative = True
 
-        self.redistribution_method = CalculationOptions.EXERGY_DESTRUCTION
+        self.redistribution_method = CalculationOptions.RELATIVE_COST
         self.calculate_component_decomposition = True
 
     @property
